==> zio-aws-ecs_2.13-5.17.155.1-sources.jar: zio/aws/ecs/model/DeleteAttributesRequest.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteAttributesRequest(
    cluster: Option[String] = None,
    attributes: Iterable[zio.aws.ecs.model.Attribute]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.DeleteAttributesRequest = {
    import DeleteAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.DeleteAttributesRequest
      .builder()
      .optionallyWith(cluster.map(value => value: java.lang.String))(_.cluster)
      .attributes(attributes.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.DeleteAttributesRequest.ReadOnly =
    zio.aws.ecs.model.DeleteAttributesRequest.wrap(buildAwsValue())
}
object DeleteAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.DeleteAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.DeleteAttributesRequest =
      zio.aws.ecs.model.DeleteAttributesRequest(
        cluster.map(value => value),
        attributes.map { item =>
          item.asEditable
        }
      )
    def cluster: Option[String]
    def attributes: List[zio.aws.ecs.model.Attribute.ReadOnly]
    def getCluster: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("cluster", cluster)
    def getAttributes
        : ZIO[Any, Nothing, List[zio.aws.ecs.model.Attribute.ReadOnly]] =
      ZIO.succeed(attributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.DeleteAttributesRequest
  ) extends zio.aws.ecs.model.DeleteAttributesRequest.ReadOnly {
    override val cluster: Option[String] =
      scala.Option(impl.cluster()).map(value => value: String)
    override val attributes: List[zio.aws.ecs.model.Attribute.ReadOnly] = impl
      .attributes()
      .asScala
      .map { item =>
        zio.aws.ecs.model.Attribute.wrap(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.DeleteAttributesRequest
  ): zio.aws.ecs.model.DeleteAttributesRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ecs_2.13-5.17.257.1-sources.jar: zio/aws/ecs/model/DeleteAttributesRequest.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteAttributesRequest(
    cluster: Optional[String] = Optional.Absent,
    attributes: Iterable[zio.aws.ecs.model.Attribute]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.DeleteAttributesRequest = {
    import DeleteAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.DeleteAttributesRequest
      .builder()
      .optionallyWith(cluster.map(value => value: java.lang.String))(_.cluster)
      .attributes(attributes.map { item =>
        item.buildAwsValue()
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.DeleteAttributesRequest.ReadOnly =
    zio.aws.ecs.model.DeleteAttributesRequest.wrap(buildAwsValue())
}
object DeleteAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.DeleteAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.DeleteAttributesRequest =
      zio.aws.ecs.model.DeleteAttributesRequest(
        cluster.map(value => value),
        attributes.map { item =>
          item.asEditable
        }
      )
    def cluster: Optional[String]
    def attributes: List[zio.aws.ecs.model.Attribute.ReadOnly]
    def getCluster: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("cluster", cluster)
    def getAttributes
        : ZIO[Any, Nothing, List[zio.aws.ecs.model.Attribute.ReadOnly]] =
      ZIO.succeed(attributes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.DeleteAttributesRequest
  ) extends zio.aws.ecs.model.DeleteAttributesRequest.ReadOnly {
    override val cluster: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.cluster())
      .map(value => value: String)
    override val attributes: List[zio.aws.ecs.model.Attribute.ReadOnly] = impl
      .attributes()
      .asScala
      .map { item =>
        zio.aws.ecs.model.Attribute.wrap(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.DeleteAttributesRequest
  ): zio.aws.ecs.model.DeleteAttributesRequest.ReadOnly = new Wrapper(impl)
}
